@@ -6,7 +6,7 @@ import os
 from palo_alto_firewall_analyzer.pan_api import pan_api
 from palo_alto_firewall_analyzer.pan_helpers import load_API_key
 
-DEFAULT_CONFIG_DIR = os.path.expanduser("~\\.pan_policy_analyzer\\")
+DEFAULT_CONFIG_DIR = os.path.expanduser("~" + os.sep + ".pan_policy_analyzer" + os.sep)
 DEFAULT_API_KEYFILE = DEFAULT_CONFIG_DIR + "API_KEY.txt"
 
 
